Reference
=========

QtBot
-----

.. module:: pytestqt.qtbot
.. autoclass:: QtBot

TimeoutError
------------

.. autoclass:: TimeoutError

ScreenshotError
------------------

.. autoclass:: ScreenshotError


SignalEmittedError
------------------

.. autoclass:: SignalEmittedError


CallbackCalledTwiceError
------------------------

.. autoclass:: CallbackCalledTwiceError


SignalBlocker
-------------

.. module:: pytestqt.wait_signal
.. autoclass:: SignalBlocker

MultiSignalBlocker
------------------

.. autoclass:: MultiSignalBlocker


Record
------

.. module:: pytestqt.logging
.. autoclass:: Record

.. _qapp-fixture:

qapp fixture
------------

.. module:: pytestqt.plugin
.. autofunction:: qapp
.. autofunction:: qapp_args
